@@ -1,8 +1,3 @@
-import os
-
-DEBUG = True
-TEMPLATE_DEBUG = DEBUG
-
 ADMINS = ()
 
 MANAGERS = ADMINS
@@ -42,10 +37,25 @@ STATICFILES_FINDERS = (
 # Make this unique, and don't share it with anybody.
 SECRET_KEY = "1234567890evonove"
 
-TEMPLATE_LOADERS = (
-    'django.template.loaders.filesystem.Loader',
-    'django.template.loaders.app_directories.Loader',
-)
+TEMPLATES = [
+    {
+        'BACKEND': 'django.template.backends.django.DjangoTemplates',
+        'DIRS': [],
+        'APP_DIRS': True,
+        'OPTIONS': {
+            'debug': True,
+            'context_processors': [
+                'django.contrib.auth.context_processors.auth',
+                'django.template.context_processors.debug',
+                'django.template.context_processors.i18n',
+                'django.template.context_processors.media',
+                'django.template.context_processors.static',
+                'django.template.context_processors.tz',
+                'django.contrib.messages.context_processors.messages',
+            ],
+        },
+    },
+]
 
 MIDDLEWARE_CLASSES = (
     'django.middleware.common.CommonMiddleware',
@@ -57,8 +67,6 @@ MIDDLEWARE_CLASSES = (
 
 ROOT_URLCONF = 'oauth2_provider.tests.urls'
 
-TEMPLATE_DIRS = ()
-
 INSTALLED_APPS = (
     'django.contrib.auth',
     'django.contrib.contenttypes',
@@ -120,11 +128,3 @@ LOGGING = {
 OAUTH2_PROVIDER = {
     '_SCOPES': ['example']
 }
-
-import django
-
-if django.VERSION[:2] < (1, 6):
-    TEST_RUNNER = 'discover_runner.DiscoverRunner'
-    INSTALLED_APPS += ('discover_runner',)
-else:
-    TEST_RUNNER = 'django.test.runner.DiscoverRunner'
