@@ -1,14 +1,13 @@
 from __future__ import unicode_literals
 
-import mock
-
-from django.test import TestCase, RequestFactory
+from django.contrib.auth import get_user_model
 from django.core.urlresolvers import reverse
+from django.test import TestCase, RequestFactory
 
-from ..compat import urlparse, parse_qs, urlencode, get_user_model
+from ..compat import urlparse, parse_qs, urlencode
 from ..models import get_application_model
 from ..settings import oauth2_settings
-from ..views import ProtectedResourceView, AuthorizationView
+from ..views import ProtectedResourceView
 
 
 Application = get_application_model()
