@@ -1,18 +1,13 @@
 from __future__ import unicode_literals
 
-try:
-    from unittest import skipIf
-except ImportError:
-    from django.utils.unittest.case import skipIf
-
 import django
+from django.contrib.auth import get_user_model
+from django.core.exceptions import ValidationError
 from django.test import TestCase
 from django.test.utils import override_settings
-from django.core.exceptions import ValidationError
 from django.utils import timezone
 
 from ..models import get_application_model, Grant, AccessToken, RefreshToken
-from ..compat import get_user_model
 
 
 Application = get_application_model()
@@ -112,7 +107,6 @@ class TestModels(TestCase):
         self.assertEqual(access_token2.scopes, {'write': 'Writing scope'})
 
 
-@skipIf(django.VERSION < (1, 5), "Behavior is broken on 1.4 and there is no solution")
 @override_settings(OAUTH2_PROVIDER_APPLICATION_MODEL='tests.TestApplication')
 class TestCustomApplicationModel(TestCase):
     def setUp(self):
@@ -128,7 +122,14 @@ class TestCustomApplicationModel(TestCase):
         # Django internals caches the related objects.
         if django.VERSION < (1, 8):
             del UserModel._meta._related_objects_cache
-        related_object_names = [ro.name for ro in UserModel._meta.get_all_related_objects()]
+        if django.VERSION < (1, 10):
+            related_object_names = [ro.name for ro in UserModel._meta.get_all_related_objects()]
+        else:
+            related_object_names = [
+                f.name for f in UserModel._meta.get_fields()
+                if (f.one_to_many or f.one_to_one)
+                and f.auto_created and not f.concrete
+            ]
         self.assertNotIn('oauth2_provider:application', related_object_names)
         self.assertIn('tests%stestapplication' % (':' if django.VERSION < (1, 8) else '_'),
                       related_object_names)
