@@ -1,19 +1,16 @@
+import unittest
 from datetime import timedelta
 
-from django.conf.urls import patterns, url, include
+from django.conf.urls import url, include
+from django.contrib.auth import get_user_model
 from django.http import HttpResponse
 from django.test import TestCase
+from django.test.utils import override_settings
 from django.utils import timezone
 
-try:
-    from django.utils import unittest
-except ImportError:
-    import unittest
-
 from .test_utils import TestCaseUtils
 from ..models import AccessToken, get_application_model
 from ..settings import oauth2_settings
-from ..compat import get_user_model
 
 
 Application = get_application_model()
@@ -23,7 +20,9 @@ UserModel = get_user_model()
 try:
     from rest_framework import permissions
     from rest_framework.views import APIView
+    from rest_framework.test import force_authenticate, APIRequestFactory
     from ..ext.rest_framework import OAuth2Authentication, TokenHasScope, TokenHasReadWriteScope, TokenHasResourceScope
+    from ..ext.rest_framework import IsAuthenticatedOrTokenHasScope
 
     class MockView(APIView):
         permission_classes = (permissions.IsAuthenticated,)
@@ -41,6 +40,10 @@ try:
         permission_classes = [permissions.IsAuthenticated, TokenHasScope]
         required_scopes = ['scope1']
 
+    class AuthenticatedOrScopedView(OAuth2View):
+        permission_classes = [IsAuthenticatedOrTokenHasScope]
+        required_scopes = ['scope1']
+
     class ReadWriteScopedView(OAuth2View):
         permission_classes = [permissions.IsAuthenticated, TokenHasReadWriteScope]
 
@@ -48,14 +51,14 @@ try:
         permission_classes = [permissions.IsAuthenticated, TokenHasResourceScope]
         required_scopes = ['resource1']
 
-    urlpatterns = patterns(
-        '',
+    urlpatterns = [
         url(r'^oauth2/', include('oauth2_provider.urls')),
         url(r'^oauth2-test/$', OAuth2View.as_view()),
         url(r'^oauth2-scoped-test/$', ScopedView.as_view()),
         url(r'^oauth2-read-write-test/$', ReadWriteScopedView.as_view()),
         url(r'^oauth2-resource-scoped-test/$', ResourceScopedView.as_view()),
-    )
+        url(r'^oauth2-authenticated-or-scoped-test/$', AuthenticatedOrScopedView.as_view()),
+    ]
 
     rest_framework_installed = True
 except ImportError:
@@ -69,9 +72,8 @@ class BaseTest(TestCaseUtils, TestCase):
     pass
 
 
+@override_settings(ROOT_URLCONF=__name__)
 class TestOAuth2Authentication(BaseTest):
-    urls = 'oauth2_provider.tests.test_rest_framework'
-
     def setUp(self):
         oauth2_settings._SCOPES = ['read', 'write', 'scope1', 'scope2', 'resource1']
 
@@ -109,6 +111,24 @@ class TestOAuth2Authentication(BaseTest):
         response = self.client.get("/oauth2-test/", HTTP_AUTHORIZATION=auth)
         self.assertEqual(response.status_code, 401)
 
+    @unittest.skipUnless(rest_framework_installed, 'djangorestframework not installed')
+    def test_authentication_or_scope_denied(self):
+        # user is not authenticated
+        # not a correct token
+        auth = self._create_authorization_header("fake-token")
+        response = self.client.get("/oauth2-authenticated-or-scoped-test/", HTTP_AUTHORIZATION=auth)
+        self.assertEqual(response.status_code, 401)
+        # token doesn't have correct scope
+        auth = self._create_authorization_header(self.access_token.token)
+
+        factory = APIRequestFactory()
+        request = factory.get("/oauth2-authenticated-or-scoped-test/")
+        request.auth = auth
+        force_authenticate(request, token=self.access_token)
+        response = AuthenticatedOrScopedView.as_view()(request)
+        # authenticated but wrong scope, this is 403, not 401
+        self.assertEqual(response.status_code, 403)
+
     @unittest.skipUnless(rest_framework_installed, 'djangorestframework not installed')
     def test_scoped_permission_allow(self):
         self.access_token.scope = 'scope1'
@@ -118,6 +138,33 @@ class TestOAuth2Authentication(BaseTest):
         response = self.client.get("/oauth2-scoped-test/", HTTP_AUTHORIZATION=auth)
         self.assertEqual(response.status_code, 200)
 
+    @unittest.skipUnless(rest_framework_installed, 'djangorestframework not installed')
+    def test_authenticated_or_scoped_permission_allow(self):
+        self.access_token.scope = 'scope1'
+        self.access_token.save()
+        # correct token and correct scope
+        auth = self._create_authorization_header(self.access_token.token)
+        response = self.client.get("/oauth2-authenticated-or-scoped-test/", HTTP_AUTHORIZATION=auth)
+        self.assertEqual(response.status_code, 200)
+
+        auth = self._create_authorization_header("fake-token")
+        # incorrect token  but authenticated
+        factory = APIRequestFactory()
+        request = factory.get("/oauth2-authenticated-or-scoped-test/")
+        request.auth = auth
+        force_authenticate(request, self.test_user)
+        response = AuthenticatedOrScopedView.as_view()(request)
+        self.assertEqual(response.status_code, 200)
+
+        # correct token  but not authenticated
+        request = factory.get("/oauth2-authenticated-or-scoped-test/")
+        request.auth = auth
+        self.access_token.scope = 'scope1'
+        self.access_token.save()
+        force_authenticate(request, token=self.access_token)
+        response = AuthenticatedOrScopedView.as_view()(request)
+        self.assertEqual(response.status_code, 200)
+
     @unittest.skipUnless(rest_framework_installed, 'djangorestframework not installed')
     def test_scoped_permission_deny(self):
         self.access_token.scope = 'scope2'
