@@ -4,7 +4,7 @@ from django.contrib import admin
 admin.autodiscover()
 
 
-urlpatterns = (
+urlpatterns = [
     url(r'^admin/', include(admin.site.urls)),
     url(r'^o/', include('oauth2_provider.urls', namespace='oauth2_provider')),
-)
+]
